@@ -8,11 +8,11 @@ import datetime
 import gzip
 import io
 import json
-import mock
+from unittest import mock
 import requests_mock
 import time
 import unittest
-from six.moves import queue
+import queue
 
 
 class TestTransmissionInit(unittest.TestCase):
@@ -37,7 +37,7 @@ class TestTransmissionInit(unittest.TestCase):
 
     def test_user_agent_addition(self):
         ''' ensure user_agent_addition is included in the User-Agent header '''
-        with mock.patch('libhoney.transmission.requests.Session') as m_session:
+        with mock.patch('libhoney.transmission.Transmission._get_requests_session') as m_session:
             transmission.Transmission(
                 user_agent_addition='foo/1.0', gzip_enabled=False)
             expected = "libhoney-py/" + libhoney.version.VERSION + " foo/1.0"
